<h1>Helper functions</h1>
<p>This page will describe the helper functions available through the helpdesk framework.</p>
<h2>Clean Functions</h2>
<p>These functions exist to help you clean user data to avoid XSS and other vulnerabilities.  Also, it makes strange characters display and store cleanly.</p>
<p>These functions are named clean_(source)_(destination).  All you have to do is assign the results of the function call to some variable, and you're finished.  Example: $result = clean_form_display($dirty_variable);</p>
<h4>Input sources</h4>
<ul>
<li>Form</li>
<li>SQL</li>
</ul>
<h4>Output destinations</h4>
<ul>
<li>Form</li>
<li>SQL</li>
<li>Display</li>
<li>URL</li>
</ul>
<h2>Date Functions</h2>
<p>These functions help you deal with common date-related problems.</p>
<h3>display_date_dropdown ($time, $name, $granularity)</h3>
<p>This function generates a set of pulldown boxes that represents a date.</p>
<h4>Arguments</h4>
<ul>
<li>time: The default time to be selected in unix timestamp format</li>
<li>name: The name that the variables should have on submission ($_REQUEST[$name])</li>
<li>granularity: One of: date, time, both.  Determines which pulldowns to display.</li>
</ul>
<h2>Error Functions</h2>
<p>These functions deal with error handling.</p>
<h3>puke ($error)</h3>
<p>Use this function when an unrecoverable error has occured, and you want to exit gracefully.</p>
<h4>Arguments</h4>
<ul>
<li>error: The string describing exactly what happened</li>
</ul>
<h3>print_errors()</h3>
<p>Use this function to display the contents of the $errors and $warnings arrays, which are stocked by things like validation scripts.</p>
<h2>Paginate Functions</h2>
<p>This script contains the paginate function.</p>
<h3>paginate(&$array, $default_sort_column, $default_sort_direction, $number_per_page = 0, $full_width_column = "", $carry_vars="")</h3>
<p>The paginate function displays a table of values in a pretty way.</p>
<h4>Arguments</h4>
<ul>
<li>array: The two dimensional array of values to display (see explanation later)</li>
<li>default_sort_column: which column of the table to sort your values on by default</li>
<li>default_sort_direction: One of SORT_ASC, SORT_DESC.  Which direction to sort your values on by default.</li>
<li>number_per_page: The number of elements to display on each page.  If this is zero, all items will be displayed on one page.</li>
<li>full_width_column: Which column, if any, will be set to width=100% in order to stretch it to be the maximum possible size.  Good for text descriptions.</li>
<li>carry_vars: any get variables that are necessary to generate the same data set again.  The paginate function generates links which it will append these carry vars onto.</li>
</ul>
<h4>The array</h4>
<p>You must send the array in the following format:</p>
<p>$array[index_number][column]</p>
<p>$array is an array of arrays.</p>
<h4>Recommended $array generation procedure</h4>
<ul>
<li>Create an array $array</li>
<li>Set up a while loop to add all of the data to the table, one row at a time</li>
<ul>
<li>Create an array $temp</li>
<li>Add each value you want displayed onto $temp, using the heading on the table as its key.  Example: $temp = array ("col1" => "item1", "col2" => "item2");</li>
<li>array_push $temp onto $array</li>
</ul>
<li>Call the paginate function with $array as an argument</li>
</ul>
<p>You may also wish to sort on a value that's not the same as the text display.  This, too, is handled by the pagination function.  Instead of assigning a text value to each column in $temp, you can create an array instead:</p>
<p>Example:</p>
<p>$temp = array();
<br />$temp["col1"] = array(0 => "this is what I'm sorting on", 1 => "this is what I'm actually displaying");
<br />$temp["col2"] = array(0 => "I'm sorting on this in the next column", 1 => "display");</p>
